@@ -26,8 +26,12 @@ class Compiler:
     def code(self):
         return self._code
 
-    def compile(self):
-        self._parser.parse()
+    def compile(self, markdown=False):
+        print(self._tokens)
+        if not self._parser.tree:
+            self._parser.parse()
+        self._code = ""
         for node in self._parser.tree:
-            self._code = self._code + node.eval()
+            self._code = self._code + node.eval(markdown=markdown)
+        self._code = self._code.strip()
         return self._code
